@@ -31,10 +31,12 @@ void xendwin()
 
 void xstart_color()
 {
-    int background = COLOR_BLACK;
+    int background = -1;
 
     if(has_colors()) {
         if(start_color() == OK) {
+            use_default_colors();
+
             init_pair(1, COLOR_WHITE, background);
             init_pair(2, COLOR_BLUE, background);
             init_pair(3, COLOR_CYAN, background);
@@ -166,10 +168,10 @@ void merr_msg(char* msg, ...)
         const int maxx = mgetmaxx();
 
         if(mis_raw_mode()) {
-            clear();
+            xclear();
             view();
             mclear_online(maxy-2);
-            mclear_online(maxy-1);
+            mclear_lastline();
             mvprintw(maxy-2, 0, "%s", msg2);
             refresh();
 
@@ -214,7 +216,7 @@ void msg_nonstop(char* msg, ...)
     xclear();
     view();
     mclear_online(maxy-2);
-    mclear_online(maxy-1);
+    mclear_lastline();
     mvprintw(maxy-2, 0, "%s", msg2);
     refresh();
 }
@@ -235,7 +237,7 @@ char* choise(char* msg, char* str[], int len, int cancel)
         view();
 
         mclear_online(maxy-2);
-        mclear_online(maxy-1);
+        mclear_lastline();
 
         move(maxy-2, 0);
         printw("%s", msg);
@@ -253,10 +255,8 @@ char* choise(char* msg, char* str[], int len, int cancel)
                 printw("%s ", str[i]);
             }
         }
-        move(maxy-1, maxx-2);
         refresh();
 
-
         /// input ///
         int meta;
         int key = xgetch(&meta);
@@ -323,7 +323,7 @@ void input_box_view()
 
     /// view ///
     mclear_online(maxy-2);
-    mclear_online(maxy-1);
+    mclear_lastline();
     
     mvprintw(maxy-2, 0, "%s", gInputBoxMsg);
     
@@ -351,7 +351,9 @@ int input_box(char* msg, char* result, int result_size, char* def_input, int def
     gView = input_box_view;
     
     while(1) {
-        input_box_view();
+        xclear();
+        view();
+        //input_box_view();
         refresh();
 
         /// input ///
@@ -525,7 +527,7 @@ void select_str_view()
     
     /// view ///
     mclear_online(maxy-2);
-    mclear_online(maxy-1);
+    mclear_lastline();
 
     move(maxy-2, 0);
     printw("%s", gSelectStrMsg);
@@ -545,7 +547,7 @@ void select_str_view()
         }
     }
 
-    move(maxy-1, maxx-2);
+    //move(maxy-2, 0);
 }
 
 int select_str(char* msg, char* str[], int len, int cancel)
@@ -559,9 +561,11 @@ int select_str(char* msg, char* str[], int len, int cancel)
     gView = select_str_view;
     
     while(1) {
-        filer_view(0);
-        filer_view(1);
-        select_str_view();
+        xclear();
+        view();
+        //filer_view(0);
+        //filer_view(1);
+        //select_str_view();
         refresh();
 
         /// input ///
@@ -618,10 +622,11 @@ int select_str2(char* msg, char* str[], int len, int cancel)
     
     gSelectStrCursor = 0;
     
-    gView = select_str_view;
+    //gView = select_str_view;
     
     while(1) {
-        select_str_view();
+        xclear();
+        view(); //select_str_view();
         refresh();
 
         /// input ///
@@ -712,7 +717,8 @@ void xclear()
     }
     mclear_lastline();
 #else
-    clear();
+    erase();
+    //clear();
 #endif
 }
 
@@ -721,3 +727,32 @@ void gui_init()
     gInputBoxInput = STRING_NEW_STACK("");
 }
 
+void mbox(int y, int x, int width, int height)
+{
+   char hbar[256];
+   int i;
+
+   hbar[0] = '+';
+   for(i=1; i<width-1; i++) {
+      hbar[i] = '-';
+   }
+   hbar[i] = '+';
+   hbar[i+1] = 0;
+
+   mvprintw(y, x, hbar);
+   for(i=0; i<height-2; i++) {
+       char hbar2[256];
+
+       int j;
+       hbar2[0] = '|';
+       for(j=1; j<width-1; j++) {
+           hbar2[j] = ' ';
+       }
+       hbar2[j] = '|';
+       hbar2[j+1] = 0;
+
+       mvprintw(y + 1 +i, x, hbar2);
+   }
+
+   mvprintw(y + height-1, x, hbar);
+}
