@@ -659,12 +659,100 @@ void extname(char* result, int result_size, char* name)
     xstrncpy(result, "", result_size);
 }
 
+static int gMainResult;
+
+static void temulator_fun(void* arg)
+{
+    /// start curses ///
+    xinitscr();
+
+    /// main loop ///
+    fd_set mask;
+    fd_set read_ok;
+
+    FD_ZERO(&mask);
+    FD_SET(0, &mask);
+
+    while(gMainLoop == -1) {
+        /// drawing ///
+        xclear();
+        view();
+        refresh();
+
+        const int maxy = mgetmaxy();
+        mmove_immediately(maxy-2, 0);
+
+        /// select for waiting to input ///
+        read_ok = mask;
+        if(xyzsh_job_num() > 0) {
+            struct timeval tv;
+            tv.tv_sec = 5;
+            tv.tv_usec = 0;
+
+            select(5, &read_ok, NULL, NULL, &tv);
+        }
+        else {
+            select(5, &read_ok, NULL, NULL, NULL);
+        }
+
+        /// input ///
+#ifdef HAVE_LIB_CURSESW
+        if(FD_ISSET(0, &read_ok)) {
+            int meta;
+            int* key;
+            int key_size;
+            xgetch_utf8(&meta, ALLOC &key, &key_size);
+
+            input_utf8(meta, key, key_size);
+
+            FREE(key);
+        }
+#else
+        if(FD_ISSET(0, &read_ok)) {
+            int meta;
+            int key = xgetch(&meta);
+
+            input(meta, key);
+        }
+#endif
+
+        /// works to background jobs ///
+        xyzsh_wait_background_job();
+    }
+
+    /// end curses ///
+    endwin();
+
+    /// kill all jobs ///
+    xyzsh_kill_all_jobs();
+
+    /// finalization for modules ///
+    isearch_final();
+    menu_final();
+    filer_final();
+    xyzsh_final();
+    commands_final();
+
+    mreset_tty();
+    //mrestore_ttysettings();
+
+    /// checking memory leaks ///
+    CHECKML_END();
+
+    /// puts ///
+    puts("");
+
+    mreset_tty();
+
+    gMainResult = gMainLoop;
+}
+
 int main(int argc, char* argv[])
 {
-    CHECKML_BEGIN(FALSE);    // start to watch memory leak
+    CHECKML_BEGIN();    // start to watch memory leak
 
     /// initialization for envronment variable ///
-    setenv("VERSION", "1.2.0", 1);
+    setenv("VERSION", "1.2.1", 1);
     setenv("MFILER4_DOCDIR", DOCDIR, 1);
     setenv("MFILER4_DATAROOTDIR", DOCDIR, 1);
 
@@ -844,7 +932,12 @@ int main(int argc, char* argv[])
 
     /// signal ///
     set_signal_mfiler();
-    
+
+    /// start curses ///
+//    xinitscr();
+
+    //run_on_temulator(temulator_fun, NULL);
+
     /// start curses ///
     xinitscr();
 
